j\_chess\_lib.client package
============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   j_chess_lib.client.match

Submodules
----------

j\_chess\_lib.client.Client module
----------------------------------

.. automodule:: j_chess_lib.client.Client
   :members:
   :undoc-members:
   :show-inheritance:

j\_chess\_lib.client.Exceptions module
--------------------------------------

.. automodule:: j_chess_lib.client.Exceptions
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: j_chess_lib.client
   :members:
   :undoc-members:
   :show-inheritance:
